# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        Account,
        AccountRoleData,
        AccountRoleDataRole,
        AccountRolesItem,
        AccountSort,
        AccountUserRole,
        AccountUserRoleRole,
        AccountUserRolesResponse,
        AccountUserSort,
        AccountsResponse,
        Action,
        ActionCreateResponse,
        ActionCreateResponseData,
        ActionResponse,
        ActionWithIncludes,
        ActionWithIncludesResponse,
        ActionsWithIncludesResponse,
        Anchor,
        Asset,
        AssetCommon,
        AssetCommonType,
        AssetCommonWithIncludes,
        AssetCommonWithIncludesType,
        AssetInclude,
        AssetSearchResult,
        AssetSearchResultType,
        AssetWithIncludes,
        AssigneeMatch,
        AttachmentInput,
        AudioSampleRateMatch,
        AuditLogsInclude,
        AuditLogsWithIncludesResponse,
        AuditLogwithIncludes,
        AuditLogwithIncludesEventType,
        AuditLogwithIncludesResourceType,
        BadRequest,
        BadRequestErrorsItem,
        BadRequestErrorsItemSource,
        BitDepthMatch,
        BitRateMatch,
        BooleanValue,
        ChannelsMatch,
        ChildrenType,
        CodecMatch,
        Collection,
        CollectionAggregationMode,
        CollectionInclude,
        CollectionResponse,
        CollectionsResponse,
        ColorSpaceMatch,
        Comment,
        CommentAttachment,
        CommentAttachmentResponse,
        CommentCountMatch,
        CommentInclude,
        CommentMatch,
        CommentResponse,
        CommentSort,
        CommentWithIncludes,
        CommentWithIncludesResponse,
        CommentsWithIncludesResponse,
        Conflict,
        ConflictErrorsItem,
        ConflictErrorsItemSource,
        CreatorMatch,
        DateDefinition,
        DateDefinitionFieldConfiguration,
        DateDefinitionFieldConfigurationDisplayFormat,
        DateDefinitionFieldConfigurationTimeFormat,
        DateDefinitionParams,
        DateDefinitionParamsFieldConfiguration,
        DateDefinitionParamsFieldConfigurationDisplayFormat,
        DateDefinitionParamsFieldConfigurationTimeFormat,
        DateDefinitionWithIncludes,
        DateValue,
        DeletedAtMatch,
        DurationMatch,
        DynamicRangeMatch,
        FieldDefinition,
        FieldDefinitionInclude,
        FieldDefinitionResponse,
        FieldDefinitionSort,
        FieldDefinitionWithIncludes,
        FieldDefinitionsWithIncludesResponse,
        FieldValueCommon,
        FieldValueCommonFieldType,
        File,
        FileAssetsWithIncludesResponse,
        FileRemoteUploadResponse,
        FileResponse,
        FileSort,
        FileStatus,
        FileTypeMatch,
        FileUploadStatus,
        FileUploadStatusResponse,
        FileWithIncludes,
        FileWithIncludesResponse,
        FileWithIncludesStatus,
        FileWithMediaLinksInclude,
        FilesizeMatch,
        Filters,
        FiltersEventType,
        FiltersResourceType,
        Folder,
        FolderAssetsWithIncludesResponse,
        FolderResponse,
        FolderSort,
        FolderWithIncludes,
        FolderWithIncludesResponse,
        FoldersWithIncludesResponse,
        Forbidden,
        ForbiddenErrorsItem,
        ForbiddenErrorsItemSource,
        FormatMatch,
        FrameRateMatch,
        GroupCommon,
        GroupCommonSource,
        GroupCommonWithIncludes,
        GroupResponse,
        GroupWithIncludes,
        GroupWithIncludesResponse,
        GroupsInclude,
        GroupsSort,
        GroupsWithIncludesResponse,
        HasAlphaChannelMatch,
        Include,
        IncludeTotalCount,
        InsertedAtMatch,
        IntegerValue,
        JsonErrorResponse,
        JsonErrorResponseErrorsItem,
        JsonErrorResponseErrorsItemSource,
        KeywordsMatch,
        Link,
        LinkParams,
        Links,
        LongTextDefinition,
        LongTextDefinitionFieldConfiguration,
        LongTextDefinitionParams,
        LongTextDefinitionWithIncludes,
        MediaLinkCommon,
        MediaLinksCollection,
        Mention,
        MetadataField,
        MetadataResponse,
        MetadataWithDefinition,
        MultiSelectValue,
        MultiUserValue,
        MultiUserValueMemberOptionsType,
        NameMatch,
        NoContent,
        NotFound,
        NotFoundErrorsItem,
        NotFoundErrorsItemSource,
        NotesMatch,
        NumberDefinition,
        NumberDefinitionFieldConfiguration,
        NumberDefinitionFieldConfigurationNumberFormat,
        NumberDefinitionParams,
        NumberDefinitionParamsFieldConfiguration,
        NumberDefinitionParamsFieldConfigurationNumberFormat,
        NumberDefinitionWithIncludes,
        NumberValue,
        OriginalMediaLink,
        PageCountMatch,
        Project,
        ProjectInclude,
        ProjectMatch,
        ProjectMatchInfo,
        ProjectMatchProject,
        ProjectSearchResult,
        ProjectSort,
        ProjectStatus,
        ProjectUserRolesResponse,
        ProjectWithIncludes,
        ProjectsWithIncludesResponse,
        RatingDefinition,
        RatingDefinitionFieldConfiguration,
        RatingDefinitionFieldConfigurationStyle,
        RatingDefinitionParams,
        RatingDefinitionParamsFieldConfiguration,
        RatingDefinitionParamsFieldConfigurationStyle,
        RatingDefinitionWithIncludes,
        RatingMatch,
        RenditionMediaLink,
        RequestAfterOpaqueCursor,
        RequestPageSize,
        ResolutionHeightMatch,
        ResolutionWidthMatch,
        ReviewersSort,
        ScrubSheetMediaLink,
        ScrubSheetMediaLinkMetadata,
        SearchMatch,
        SearchResponse,
        SearchResponseDataItem,
        SelectDefinition,
        SelectDefinitionFieldConfiguration,
        SelectDefinitionFieldConfigurationOptionsItem,
        SelectDefinitionParams,
        SelectDefinitionParamsFieldConfiguration,
        SelectDefinitionParamsFieldConfigurationOptionsItem,
        SelectDefinitionWithIncludes,
        SelectMultiDefinition,
        SelectMultiDefinitionFieldConfiguration,
        SelectMultiDefinitionFieldConfigurationOptionsItem,
        SelectMultiDefinitionParams,
        SelectMultiDefinitionParamsFieldConfiguration,
        SelectMultiDefinitionParamsFieldConfigurationOptionsItem,
        SelectMultiDefinitionWithIncludes,
        SelectOption,
        SelectValue,
        Share,
        ShareAccess,
        ShareReviewersResponse,
        ShareSort,
        SharesResponse,
        SingleUserValue,
        SingleUserValueMemberOptionsType,
        SourceFilenameMatch,
        StatusMatch,
        SyncGroupWithIncludes,
        SyncGroupWithIncludesSyncStatus,
        TextDefinition,
        TextDefinitionFieldConfiguration,
        TextDefinitionParams,
        TextDefinitionWithIncludes,
        TextReviewAnnotation,
        TextReviewAnnotationBounds,
        TextReviewAnnotationTextReviewAnnotationType,
        TextReviewAnnotationUpdate,
        TextReviewAnnotationUpdateTextReviewAnnotationType,
        TextValue,
        TimeStamp,
        ToggleDefinition,
        ToggleDefinitionFieldConfiguration,
        ToggleDefinitionParams,
        ToggleDefinitionParamsFieldConfiguration,
        ToggleDefinitionWithIncludes,
        TooManyRequests,
        TooManyRequestsErrorsItem,
        TooManyRequestsErrorsItemSource,
        TranscriptionMatch,
        TranscriptionMatchMatchesItem,
        Unauthorized,
        UnauthorizedErrorsItem,
        UnauthorizedErrorsItemSource,
        UnprocessableContent,
        UnprocessableContentErrorsItem,
        UnprocessableContentErrorsItemSource,
        UpdateAccountRolesResponse,
        UpdateDateDefinitionParams,
        UpdateDateDefinitionParamsFieldConfiguration,
        UpdateDateDefinitionParamsFieldConfigurationDisplayFormat,
        UpdateDateDefinitionParamsFieldConfigurationTimeFormat,
        UpdateLongTextDefinitionParams,
        UpdateNumberDefinitionParams,
        UpdateNumberDefinitionParamsFieldConfiguration,
        UpdateNumberDefinitionParamsFieldConfigurationNumberFormat,
        UpdateRatingDefinitionParams,
        UpdateRatingDefinitionParamsFieldConfiguration,
        UpdateRatingDefinitionParamsFieldConfigurationStyle,
        UpdateSelectDefinitionParams,
        UpdateSelectDefinitionParamsFieldConfiguration,
        UpdateSelectDefinitionParamsFieldConfigurationOptionsItem,
        UpdateSelectMultiDefinitionParams,
        UpdateSelectMultiDefinitionParamsFieldConfiguration,
        UpdateSelectMultiDefinitionParamsFieldConfigurationOptionsItem,
        UpdateTextDefinitionParams,
        UpdateToggleDefinitionParams,
        UpdateToggleDefinitionParamsFieldConfiguration,
        UpdateUserMultiDefinitionParams,
        UpdateUserMultiDefinitionParamsFieldConfiguration,
        UpdateUserMultiDefinitionParamsFieldConfigurationCustomMembersItem,
        UpdateUserMultiDefinitionParamsFieldConfigurationCustomMembersItemType,
        UpdateUserMultiDefinitionParamsFieldConfigurationMemberOptionsType,
        UpdateUserRolesResponse,
        UpdateUserRolesResponseData,
        UpdateUserRolesResponseDataRole,
        UpdateUserSingleDefinitionParams,
        UpdateUserSingleDefinitionParamsFieldConfiguration,
        UpdateUserSingleDefinitionParamsFieldConfigurationCustomMembersItem,
        UpdateUserSingleDefinitionParamsFieldConfigurationCustomMembersItemType,
        UpdateUserSingleDefinitionParamsFieldConfigurationMemberOptionsType,
        UpdatedAtMatch,
        UploadedAtMatch,
        User,
        UserMultiDefinition,
        UserMultiDefinitionFieldConfiguration,
        UserMultiDefinitionFieldConfigurationCustomMembersItem,
        UserMultiDefinitionFieldConfigurationCustomMembersItemType,
        UserMultiDefinitionFieldConfigurationMemberOptionsType,
        UserMultiDefinitionParams,
        UserMultiDefinitionParamsFieldConfiguration,
        UserMultiDefinitionParamsFieldConfigurationCustomMembersItem,
        UserMultiDefinitionParamsFieldConfigurationCustomMembersItemType,
        UserMultiDefinitionParamsFieldConfigurationMemberOptionsType,
        UserMultiDefinitionWithIncludes,
        UserRole,
        UserRoleRole,
        UserRoleSort,
        UserRolesResponse,
        UserSingleDefinition,
        UserSingleDefinitionFieldConfiguration,
        UserSingleDefinitionFieldConfigurationCustomMembersItem,
        UserSingleDefinitionFieldConfigurationCustomMembersItemType,
        UserSingleDefinitionFieldConfigurationMemberOptionsType,
        UserSingleDefinitionParams,
        UserSingleDefinitionParamsFieldConfiguration,
        UserSingleDefinitionParamsFieldConfigurationCustomMembersItem,
        UserSingleDefinitionParamsFieldConfigurationCustomMembersItemType,
        UserSingleDefinitionParamsFieldConfigurationMemberOptionsType,
        UserSingleDefinitionWithIncludes,
        UserValue,
        UserValueType,
        Uuid,
        VersionStack,
        VersionStackAssetsWithIncludesResponse,
        VersionStackChildrenResponse,
        VersionStackResponse,
        VersionStackSortIndex,
        VersionStackSortList,
        VersionStackWithIncludes,
        VersionStackWithIncludesResponse,
        VersionStacksWithIncludesResponse,
        VisualMatch,
        VisualMatchClip,
        VisualMatchClipsItem,
        Webhook,
        WebhookEvents,
        WebhookSort,
        WebhookWithIncludes,
        WebhooksWithIncludesResponse,
        Workspace,
        WorkspaceInclude,
        WorkspaceSort,
        WorkspaceUserRolesResponse,
        WorkspaceWithIncludes,
        WorkspacesWithIncludesResponse,
    )
    from .errors import (
        BadRequestError,
        ConflictError,
        ForbiddenError,
        NotFoundError,
        TooManyRequestsError,
        UnauthorizedError,
        UnprocessableEntityError,
    )
    from . import (
        account_permissions,
        accounts,
        collections,
        comments,
        custom_actions,
        files,
        folder_permissions,
        folders,
        groups,
        metadata,
        metadata_fields,
        project_permissions,
        projects,
        search,
        shares,
        version_stacks,
        webhooks,
        workspace_permissions,
        workspaces,
    )
    from .account_permissions import AccountUserRolesIndexRequestSort
    from .accounts import AccountsIndexRequestSort
    from .client import AsyncFrameioExperimental, FrameioExperimental
    from .comments import (
        CommentsIndexRequestInclude,
        CommentsIndexRequestSort,
        CommentsShowRequestInclude,
        CreateCommentParamsData,
        UpdateCommentParamsData,
    )
    from .custom_actions import ActionCreateParamsData, ActionUpdateParamsData
    from .environment import FrameioExperimentalEnvironment
    from .files import (
        FileCreateRemoteUploadParamsData,
        FileImportParamsData,
        FileMoveParamsData,
        FileUpdateParamsData,
        FilesListRequestInclude,
        FilesListRequestSort,
        FilesShowRequestInclude,
    )
    from .folder_permissions import UpdateUserRolesParamsData, UpdateUserRolesParamsDataRole
    from .folders import (
        FolderCreateParamsData,
        FolderMoveParamsData,
        FolderUpdateParamsData,
        FoldersIndexRequestInclude,
        FoldersIndexRequestSort,
        FoldersListRequestInclude,
        FoldersListRequestSort,
        FoldersShowRequestInclude,
    )
    from .groups import CreateGroupParamsData, GroupsIndexRequestSort, UpdateGroupParamsData
    from .metadata import BulkUpdateMetadataParamsData, BulkUpdateMetadataParamsDataValuesItem
    from .metadata_fields import (
        CreateFieldDefinitionParamsData,
        MetadataFieldDefinitionsIndexRequestSort,
        UpdateFieldDefinitionParamsData,
    )
    from .project_permissions import ProjectUserRolesIndexRequestSort
    from .projects import AccountProjectsIndexRequestSort, ProjectsIndexRequestSort
    from .search import SearchParamsEngine, SearchParamsFilters
    from .shares import SharesIndexRequestSort, SharesListReviewersRequestSort
    from .version import __version__
    from .version_stacks import (
        VersionStackCreateParamsData,
        VersionStackMoveParamsData,
        VersionStackReorderParamsData,
        VersionStackReorderParamsDataMoveTo,
        VersionStacksIndexRequestInclude,
        VersionStacksIndexRequestSort,
        VersionStacksListRequestInclude,
        VersionStacksListRequestSort,
        VersionStacksShowRequestInclude,
    )
    from .webhooks import WebhooksIndexRequestSort
    from .workspace_permissions import WorkspaceUserRolesIndexRequestSort
    from .workspaces import WorkspacesIndexRequestSort
_dynamic_imports: typing.Dict[str, str] = {
    "Account": ".types",
    "AccountProjectsIndexRequestSort": ".projects",
    "AccountRoleData": ".types",
    "AccountRoleDataRole": ".types",
    "AccountRolesItem": ".types",
    "AccountSort": ".types",
    "AccountUserRole": ".types",
    "AccountUserRoleRole": ".types",
    "AccountUserRolesIndexRequestSort": ".account_permissions",
    "AccountUserRolesResponse": ".types",
    "AccountUserSort": ".types",
    "AccountsIndexRequestSort": ".accounts",
    "AccountsResponse": ".types",
    "Action": ".types",
    "ActionCreateParamsData": ".custom_actions",
    "ActionCreateResponse": ".types",
    "ActionCreateResponseData": ".types",
    "ActionResponse": ".types",
    "ActionUpdateParamsData": ".custom_actions",
    "ActionWithIncludes": ".types",
    "ActionWithIncludesResponse": ".types",
    "ActionsWithIncludesResponse": ".types",
    "Anchor": ".types",
    "Asset": ".types",
    "AssetCommon": ".types",
    "AssetCommonType": ".types",
    "AssetCommonWithIncludes": ".types",
    "AssetCommonWithIncludesType": ".types",
    "AssetInclude": ".types",
    "AssetSearchResult": ".types",
    "AssetSearchResultType": ".types",
    "AssetWithIncludes": ".types",
    "AssigneeMatch": ".types",
    "AsyncFrameioExperimental": ".client",
    "AttachmentInput": ".types",
    "AudioSampleRateMatch": ".types",
    "AuditLogsInclude": ".types",
    "AuditLogsWithIncludesResponse": ".types",
    "AuditLogwithIncludes": ".types",
    "AuditLogwithIncludesEventType": ".types",
    "AuditLogwithIncludesResourceType": ".types",
    "BadRequest": ".types",
    "BadRequestError": ".errors",
    "BadRequestErrorsItem": ".types",
    "BadRequestErrorsItemSource": ".types",
    "BitDepthMatch": ".types",
    "BitRateMatch": ".types",
    "BooleanValue": ".types",
    "BulkUpdateMetadataParamsData": ".metadata",
    "BulkUpdateMetadataParamsDataValuesItem": ".metadata",
    "ChannelsMatch": ".types",
    "ChildrenType": ".types",
    "CodecMatch": ".types",
    "Collection": ".types",
    "CollectionAggregationMode": ".types",
    "CollectionInclude": ".types",
    "CollectionResponse": ".types",
    "CollectionsResponse": ".types",
    "ColorSpaceMatch": ".types",
    "Comment": ".types",
    "CommentAttachment": ".types",
    "CommentAttachmentResponse": ".types",
    "CommentCountMatch": ".types",
    "CommentInclude": ".types",
    "CommentMatch": ".types",
    "CommentResponse": ".types",
    "CommentSort": ".types",
    "CommentWithIncludes": ".types",
    "CommentWithIncludesResponse": ".types",
    "CommentsIndexRequestInclude": ".comments",
    "CommentsIndexRequestSort": ".comments",
    "CommentsShowRequestInclude": ".comments",
    "CommentsWithIncludesResponse": ".types",
    "Conflict": ".types",
    "ConflictError": ".errors",
    "ConflictErrorsItem": ".types",
    "ConflictErrorsItemSource": ".types",
    "CreateCommentParamsData": ".comments",
    "CreateFieldDefinitionParamsData": ".metadata_fields",
    "CreateGroupParamsData": ".groups",
    "CreatorMatch": ".types",
    "DateDefinition": ".types",
    "DateDefinitionFieldConfiguration": ".types",
    "DateDefinitionFieldConfigurationDisplayFormat": ".types",
    "DateDefinitionFieldConfigurationTimeFormat": ".types",
    "DateDefinitionParams": ".types",
    "DateDefinitionParamsFieldConfiguration": ".types",
    "DateDefinitionParamsFieldConfigurationDisplayFormat": ".types",
    "DateDefinitionParamsFieldConfigurationTimeFormat": ".types",
    "DateDefinitionWithIncludes": ".types",
    "DateValue": ".types",
    "DeletedAtMatch": ".types",
    "DurationMatch": ".types",
    "DynamicRangeMatch": ".types",
    "FieldDefinition": ".types",
    "FieldDefinitionInclude": ".types",
    "FieldDefinitionResponse": ".types",
    "FieldDefinitionSort": ".types",
    "FieldDefinitionWithIncludes": ".types",
    "FieldDefinitionsWithIncludesResponse": ".types",
    "FieldValueCommon": ".types",
    "FieldValueCommonFieldType": ".types",
    "File": ".types",
    "FileAssetsWithIncludesResponse": ".types",
    "FileCreateRemoteUploadParamsData": ".files",
    "FileImportParamsData": ".files",
    "FileMoveParamsData": ".files",
    "FileRemoteUploadResponse": ".types",
    "FileResponse": ".types",
    "FileSort": ".types",
    "FileStatus": ".types",
    "FileTypeMatch": ".types",
    "FileUpdateParamsData": ".files",
    "FileUploadStatus": ".types",
    "FileUploadStatusResponse": ".types",
    "FileWithIncludes": ".types",
    "FileWithIncludesResponse": ".types",
    "FileWithIncludesStatus": ".types",
    "FileWithMediaLinksInclude": ".types",
    "FilesListRequestInclude": ".files",
    "FilesListRequestSort": ".files",
    "FilesShowRequestInclude": ".files",
    "FilesizeMatch": ".types",
    "Filters": ".types",
    "FiltersEventType": ".types",
    "FiltersResourceType": ".types",
    "Folder": ".types",
    "FolderAssetsWithIncludesResponse": ".types",
    "FolderCreateParamsData": ".folders",
    "FolderMoveParamsData": ".folders",
    "FolderResponse": ".types",
    "FolderSort": ".types",
    "FolderUpdateParamsData": ".folders",
    "FolderWithIncludes": ".types",
    "FolderWithIncludesResponse": ".types",
    "FoldersIndexRequestInclude": ".folders",
    "FoldersIndexRequestSort": ".folders",
    "FoldersListRequestInclude": ".folders",
    "FoldersListRequestSort": ".folders",
    "FoldersShowRequestInclude": ".folders",
    "FoldersWithIncludesResponse": ".types",
    "Forbidden": ".types",
    "ForbiddenError": ".errors",
    "ForbiddenErrorsItem": ".types",
    "ForbiddenErrorsItemSource": ".types",
    "FormatMatch": ".types",
    "FrameRateMatch": ".types",
    "FrameioExperimental": ".client",
    "FrameioExperimentalEnvironment": ".environment",
    "GroupCommon": ".types",
    "GroupCommonSource": ".types",
    "GroupCommonWithIncludes": ".types",
    "GroupResponse": ".types",
    "GroupWithIncludes": ".types",
    "GroupWithIncludesResponse": ".types",
    "GroupsInclude": ".types",
    "GroupsIndexRequestSort": ".groups",
    "GroupsSort": ".types",
    "GroupsWithIncludesResponse": ".types",
    "HasAlphaChannelMatch": ".types",
    "Include": ".types",
    "IncludeTotalCount": ".types",
    "InsertedAtMatch": ".types",
    "IntegerValue": ".types",
    "JsonErrorResponse": ".types",
    "JsonErrorResponseErrorsItem": ".types",
    "JsonErrorResponseErrorsItemSource": ".types",
    "KeywordsMatch": ".types",
    "Link": ".types",
    "LinkParams": ".types",
    "Links": ".types",
    "LongTextDefinition": ".types",
    "LongTextDefinitionFieldConfiguration": ".types",
    "LongTextDefinitionParams": ".types",
    "LongTextDefinitionWithIncludes": ".types",
    "MediaLinkCommon": ".types",
    "MediaLinksCollection": ".types",
    "Mention": ".types",
    "MetadataField": ".types",
    "MetadataFieldDefinitionsIndexRequestSort": ".metadata_fields",
    "MetadataResponse": ".types",
    "MetadataWithDefinition": ".types",
    "MultiSelectValue": ".types",
    "MultiUserValue": ".types",
    "MultiUserValueMemberOptionsType": ".types",
    "NameMatch": ".types",
    "NoContent": ".types",
    "NotFound": ".types",
    "NotFoundError": ".errors",
    "NotFoundErrorsItem": ".types",
    "NotFoundErrorsItemSource": ".types",
    "NotesMatch": ".types",
    "NumberDefinition": ".types",
    "NumberDefinitionFieldConfiguration": ".types",
    "NumberDefinitionFieldConfigurationNumberFormat": ".types",
    "NumberDefinitionParams": ".types",
    "NumberDefinitionParamsFieldConfiguration": ".types",
    "NumberDefinitionParamsFieldConfigurationNumberFormat": ".types",
    "NumberDefinitionWithIncludes": ".types",
    "NumberValue": ".types",
    "OriginalMediaLink": ".types",
    "PageCountMatch": ".types",
    "Project": ".types",
    "ProjectInclude": ".types",
    "ProjectMatch": ".types",
    "ProjectMatchInfo": ".types",
    "ProjectMatchProject": ".types",
    "ProjectSearchResult": ".types",
    "ProjectSort": ".types",
    "ProjectStatus": ".types",
    "ProjectUserRolesIndexRequestSort": ".project_permissions",
    "ProjectUserRolesResponse": ".types",
    "ProjectWithIncludes": ".types",
    "ProjectsIndexRequestSort": ".projects",
    "ProjectsWithIncludesResponse": ".types",
    "RatingDefinition": ".types",
    "RatingDefinitionFieldConfiguration": ".types",
    "RatingDefinitionFieldConfigurationStyle": ".types",
    "RatingDefinitionParams": ".types",
    "RatingDefinitionParamsFieldConfiguration": ".types",
    "RatingDefinitionParamsFieldConfigurationStyle": ".types",
    "RatingDefinitionWithIncludes": ".types",
    "RatingMatch": ".types",
    "RenditionMediaLink": ".types",
    "RequestAfterOpaqueCursor": ".types",
    "RequestPageSize": ".types",
    "ResolutionHeightMatch": ".types",
    "ResolutionWidthMatch": ".types",
    "ReviewersSort": ".types",
    "ScrubSheetMediaLink": ".types",
    "ScrubSheetMediaLinkMetadata": ".types",
    "SearchMatch": ".types",
    "SearchParamsEngine": ".search",
    "SearchParamsFilters": ".search",
    "SearchResponse": ".types",
    "SearchResponseDataItem": ".types",
    "SelectDefinition": ".types",
    "SelectDefinitionFieldConfiguration": ".types",
    "SelectDefinitionFieldConfigurationOptionsItem": ".types",
    "SelectDefinitionParams": ".types",
    "SelectDefinitionParamsFieldConfiguration": ".types",
    "SelectDefinitionParamsFieldConfigurationOptionsItem": ".types",
    "SelectDefinitionWithIncludes": ".types",
    "SelectMultiDefinition": ".types",
    "SelectMultiDefinitionFieldConfiguration": ".types",
    "SelectMultiDefinitionFieldConfigurationOptionsItem": ".types",
    "SelectMultiDefinitionParams": ".types",
    "SelectMultiDefinitionParamsFieldConfiguration": ".types",
    "SelectMultiDefinitionParamsFieldConfigurationOptionsItem": ".types",
    "SelectMultiDefinitionWithIncludes": ".types",
    "SelectOption": ".types",
    "SelectValue": ".types",
    "Share": ".types",
    "ShareAccess": ".types",
    "ShareReviewersResponse": ".types",
    "ShareSort": ".types",
    "SharesIndexRequestSort": ".shares",
    "SharesListReviewersRequestSort": ".shares",
    "SharesResponse": ".types",
    "SingleUserValue": ".types",
    "SingleUserValueMemberOptionsType": ".types",
    "SourceFilenameMatch": ".types",
    "StatusMatch": ".types",
    "SyncGroupWithIncludes": ".types",
    "SyncGroupWithIncludesSyncStatus": ".types",
    "TextDefinition": ".types",
    "TextDefinitionFieldConfiguration": ".types",
    "TextDefinitionParams": ".types",
    "TextDefinitionWithIncludes": ".types",
    "TextReviewAnnotation": ".types",
    "TextReviewAnnotationBounds": ".types",
    "TextReviewAnnotationTextReviewAnnotationType": ".types",
    "TextReviewAnnotationUpdate": ".types",
    "TextReviewAnnotationUpdateTextReviewAnnotationType": ".types",
    "TextValue": ".types",
    "TimeStamp": ".types",
    "ToggleDefinition": ".types",
    "ToggleDefinitionFieldConfiguration": ".types",
    "ToggleDefinitionParams": ".types",
    "ToggleDefinitionParamsFieldConfiguration": ".types",
    "ToggleDefinitionWithIncludes": ".types",
    "TooManyRequests": ".types",
    "TooManyRequestsError": ".errors",
    "TooManyRequestsErrorsItem": ".types",
    "TooManyRequestsErrorsItemSource": ".types",
    "TranscriptionMatch": ".types",
    "TranscriptionMatchMatchesItem": ".types",
    "Unauthorized": ".types",
    "UnauthorizedError": ".errors",
    "UnauthorizedErrorsItem": ".types",
    "UnauthorizedErrorsItemSource": ".types",
    "UnprocessableContent": ".types",
    "UnprocessableContentErrorsItem": ".types",
    "UnprocessableContentErrorsItemSource": ".types",
    "UnprocessableEntityError": ".errors",
    "UpdateAccountRolesResponse": ".types",
    "UpdateCommentParamsData": ".comments",
    "UpdateDateDefinitionParams": ".types",
    "UpdateDateDefinitionParamsFieldConfiguration": ".types",
    "UpdateDateDefinitionParamsFieldConfigurationDisplayFormat": ".types",
    "UpdateDateDefinitionParamsFieldConfigurationTimeFormat": ".types",
    "UpdateFieldDefinitionParamsData": ".metadata_fields",
    "UpdateGroupParamsData": ".groups",
    "UpdateLongTextDefinitionParams": ".types",
    "UpdateNumberDefinitionParams": ".types",
    "UpdateNumberDefinitionParamsFieldConfiguration": ".types",
    "UpdateNumberDefinitionParamsFieldConfigurationNumberFormat": ".types",
    "UpdateRatingDefinitionParams": ".types",
    "UpdateRatingDefinitionParamsFieldConfiguration": ".types",
    "UpdateRatingDefinitionParamsFieldConfigurationStyle": ".types",
    "UpdateSelectDefinitionParams": ".types",
    "UpdateSelectDefinitionParamsFieldConfiguration": ".types",
    "UpdateSelectDefinitionParamsFieldConfigurationOptionsItem": ".types",
    "UpdateSelectMultiDefinitionParams": ".types",
    "UpdateSelectMultiDefinitionParamsFieldConfiguration": ".types",
    "UpdateSelectMultiDefinitionParamsFieldConfigurationOptionsItem": ".types",
    "UpdateTextDefinitionParams": ".types",
    "UpdateToggleDefinitionParams": ".types",
    "UpdateToggleDefinitionParamsFieldConfiguration": ".types",
    "UpdateUserMultiDefinitionParams": ".types",
    "UpdateUserMultiDefinitionParamsFieldConfiguration": ".types",
    "UpdateUserMultiDefinitionParamsFieldConfigurationCustomMembersItem": ".types",
    "UpdateUserMultiDefinitionParamsFieldConfigurationCustomMembersItemType": ".types",
    "UpdateUserMultiDefinitionParamsFieldConfigurationMemberOptionsType": ".types",
    "UpdateUserRolesParamsData": ".folder_permissions",
    "UpdateUserRolesParamsDataRole": ".folder_permissions",
    "UpdateUserRolesResponse": ".types",
    "UpdateUserRolesResponseData": ".types",
    "UpdateUserRolesResponseDataRole": ".types",
    "UpdateUserSingleDefinitionParams": ".types",
    "UpdateUserSingleDefinitionParamsFieldConfiguration": ".types",
    "UpdateUserSingleDefinitionParamsFieldConfigurationCustomMembersItem": ".types",
    "UpdateUserSingleDefinitionParamsFieldConfigurationCustomMembersItemType": ".types",
    "UpdateUserSingleDefinitionParamsFieldConfigurationMemberOptionsType": ".types",
    "UpdatedAtMatch": ".types",
    "UploadedAtMatch": ".types",
    "User": ".types",
    "UserMultiDefinition": ".types",
    "UserMultiDefinitionFieldConfiguration": ".types",
    "UserMultiDefinitionFieldConfigurationCustomMembersItem": ".types",
    "UserMultiDefinitionFieldConfigurationCustomMembersItemType": ".types",
    "UserMultiDefinitionFieldConfigurationMemberOptionsType": ".types",
    "UserMultiDefinitionParams": ".types",
    "UserMultiDefinitionParamsFieldConfiguration": ".types",
    "UserMultiDefinitionParamsFieldConfigurationCustomMembersItem": ".types",
    "UserMultiDefinitionParamsFieldConfigurationCustomMembersItemType": ".types",
    "UserMultiDefinitionParamsFieldConfigurationMemberOptionsType": ".types",
    "UserMultiDefinitionWithIncludes": ".types",
    "UserRole": ".types",
    "UserRoleRole": ".types",
    "UserRoleSort": ".types",
    "UserRolesResponse": ".types",
    "UserSingleDefinition": ".types",
    "UserSingleDefinitionFieldConfiguration": ".types",
    "UserSingleDefinitionFieldConfigurationCustomMembersItem": ".types",
    "UserSingleDefinitionFieldConfigurationCustomMembersItemType": ".types",
    "UserSingleDefinitionFieldConfigurationMemberOptionsType": ".types",
    "UserSingleDefinitionParams": ".types",
    "UserSingleDefinitionParamsFieldConfiguration": ".types",
    "UserSingleDefinitionParamsFieldConfigurationCustomMembersItem": ".types",
    "UserSingleDefinitionParamsFieldConfigurationCustomMembersItemType": ".types",
    "UserSingleDefinitionParamsFieldConfigurationMemberOptionsType": ".types",
    "UserSingleDefinitionWithIncludes": ".types",
    "UserValue": ".types",
    "UserValueType": ".types",
    "Uuid": ".types",
    "VersionStack": ".types",
    "VersionStackAssetsWithIncludesResponse": ".types",
    "VersionStackChildrenResponse": ".types",
    "VersionStackCreateParamsData": ".version_stacks",
    "VersionStackMoveParamsData": ".version_stacks",
    "VersionStackReorderParamsData": ".version_stacks",
    "VersionStackReorderParamsDataMoveTo": ".version_stacks",
    "VersionStackResponse": ".types",
    "VersionStackSortIndex": ".types",
    "VersionStackSortList": ".types",
    "VersionStackWithIncludes": ".types",
    "VersionStackWithIncludesResponse": ".types",
    "VersionStacksIndexRequestInclude": ".version_stacks",
    "VersionStacksIndexRequestSort": ".version_stacks",
    "VersionStacksListRequestInclude": ".version_stacks",
    "VersionStacksListRequestSort": ".version_stacks",
    "VersionStacksShowRequestInclude": ".version_stacks",
    "VersionStacksWithIncludesResponse": ".types",
    "VisualMatch": ".types",
    "VisualMatchClip": ".types",
    "VisualMatchClipsItem": ".types",
    "Webhook": ".types",
    "WebhookEvents": ".types",
    "WebhookSort": ".types",
    "WebhookWithIncludes": ".types",
    "WebhooksIndexRequestSort": ".webhooks",
    "WebhooksWithIncludesResponse": ".types",
    "Workspace": ".types",
    "WorkspaceInclude": ".types",
    "WorkspaceSort": ".types",
    "WorkspaceUserRolesIndexRequestSort": ".workspace_permissions",
    "WorkspaceUserRolesResponse": ".types",
    "WorkspaceWithIncludes": ".types",
    "WorkspacesIndexRequestSort": ".workspaces",
    "WorkspacesWithIncludesResponse": ".types",
    "__version__": ".version",
    "account_permissions": ".account_permissions",
    "accounts": ".accounts",
    "collections": ".collections",
    "comments": ".comments",
    "custom_actions": ".custom_actions",
    "files": ".files",
    "folder_permissions": ".folder_permissions",
    "folders": ".folders",
    "groups": ".groups",
    "metadata": ".metadata",
    "metadata_fields": ".metadata_fields",
    "project_permissions": ".project_permissions",
    "projects": ".projects",
    "search": ".search",
    "shares": ".shares",
    "version_stacks": ".version_stacks",
    "webhooks": ".webhooks",
    "workspace_permissions": ".workspace_permissions",
    "workspaces": ".workspaces",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "Account",
    "AccountProjectsIndexRequestSort",
    "AccountRoleData",
    "AccountRoleDataRole",
    "AccountRolesItem",
    "AccountSort",
    "AccountUserRole",
    "AccountUserRoleRole",
    "AccountUserRolesIndexRequestSort",
    "AccountUserRolesResponse",
    "AccountUserSort",
    "AccountsIndexRequestSort",
    "AccountsResponse",
    "Action",
    "ActionCreateParamsData",
    "ActionCreateResponse",
    "ActionCreateResponseData",
    "ActionResponse",
    "ActionUpdateParamsData",
    "ActionWithIncludes",
    "ActionWithIncludesResponse",
    "ActionsWithIncludesResponse",
    "Anchor",
    "Asset",
    "AssetCommon",
    "AssetCommonType",
    "AssetCommonWithIncludes",
    "AssetCommonWithIncludesType",
    "AssetInclude",
    "AssetSearchResult",
    "AssetSearchResultType",
    "AssetWithIncludes",
    "AssigneeMatch",
    "AsyncFrameioExperimental",
    "AttachmentInput",
    "AudioSampleRateMatch",
    "AuditLogsInclude",
    "AuditLogsWithIncludesResponse",
    "AuditLogwithIncludes",
    "AuditLogwithIncludesEventType",
    "AuditLogwithIncludesResourceType",
    "BadRequest",
    "BadRequestError",
    "BadRequestErrorsItem",
    "BadRequestErrorsItemSource",
    "BitDepthMatch",
    "BitRateMatch",
    "BooleanValue",
    "BulkUpdateMetadataParamsData",
    "BulkUpdateMetadataParamsDataValuesItem",
    "ChannelsMatch",
    "ChildrenType",
    "CodecMatch",
    "Collection",
    "CollectionAggregationMode",
    "CollectionInclude",
    "CollectionResponse",
    "CollectionsResponse",
    "ColorSpaceMatch",
    "Comment",
    "CommentAttachment",
    "CommentAttachmentResponse",
    "CommentCountMatch",
    "CommentInclude",
    "CommentMatch",
    "CommentResponse",
    "CommentSort",
    "CommentWithIncludes",
    "CommentWithIncludesResponse",
    "CommentsIndexRequestInclude",
    "CommentsIndexRequestSort",
    "CommentsShowRequestInclude",
    "CommentsWithIncludesResponse",
    "Conflict",
    "ConflictError",
    "ConflictErrorsItem",
    "ConflictErrorsItemSource",
    "CreateCommentParamsData",
    "CreateFieldDefinitionParamsData",
    "CreateGroupParamsData",
    "CreatorMatch",
    "DateDefinition",
    "DateDefinitionFieldConfiguration",
    "DateDefinitionFieldConfigurationDisplayFormat",
    "DateDefinitionFieldConfigurationTimeFormat",
    "DateDefinitionParams",
    "DateDefinitionParamsFieldConfiguration",
    "DateDefinitionParamsFieldConfigurationDisplayFormat",
    "DateDefinitionParamsFieldConfigurationTimeFormat",
    "DateDefinitionWithIncludes",
    "DateValue",
    "DeletedAtMatch",
    "DurationMatch",
    "DynamicRangeMatch",
    "FieldDefinition",
    "FieldDefinitionInclude",
    "FieldDefinitionResponse",
    "FieldDefinitionSort",
    "FieldDefinitionWithIncludes",
    "FieldDefinitionsWithIncludesResponse",
    "FieldValueCommon",
    "FieldValueCommonFieldType",
    "File",
    "FileAssetsWithIncludesResponse",
    "FileCreateRemoteUploadParamsData",
    "FileImportParamsData",
    "FileMoveParamsData",
    "FileRemoteUploadResponse",
    "FileResponse",
    "FileSort",
    "FileStatus",
    "FileTypeMatch",
    "FileUpdateParamsData",
    "FileUploadStatus",
    "FileUploadStatusResponse",
    "FileWithIncludes",
    "FileWithIncludesResponse",
    "FileWithIncludesStatus",
    "FileWithMediaLinksInclude",
    "FilesListRequestInclude",
    "FilesListRequestSort",
    "FilesShowRequestInclude",
    "FilesizeMatch",
    "Filters",
    "FiltersEventType",
    "FiltersResourceType",
    "Folder",
    "FolderAssetsWithIncludesResponse",
    "FolderCreateParamsData",
    "FolderMoveParamsData",
    "FolderResponse",
    "FolderSort",
    "FolderUpdateParamsData",
    "FolderWithIncludes",
    "FolderWithIncludesResponse",
    "FoldersIndexRequestInclude",
    "FoldersIndexRequestSort",
    "FoldersListRequestInclude",
    "FoldersListRequestSort",
    "FoldersShowRequestInclude",
    "FoldersWithIncludesResponse",
    "Forbidden",
    "ForbiddenError",
    "ForbiddenErrorsItem",
    "ForbiddenErrorsItemSource",
    "FormatMatch",
    "FrameRateMatch",
    "FrameioExperimental",
    "FrameioExperimentalEnvironment",
    "GroupCommon",
    "GroupCommonSource",
    "GroupCommonWithIncludes",
    "GroupResponse",
    "GroupWithIncludes",
    "GroupWithIncludesResponse",
    "GroupsInclude",
    "GroupsIndexRequestSort",
    "GroupsSort",
    "GroupsWithIncludesResponse",
    "HasAlphaChannelMatch",
    "Include",
    "IncludeTotalCount",
    "InsertedAtMatch",
    "IntegerValue",
    "JsonErrorResponse",
    "JsonErrorResponseErrorsItem",
    "JsonErrorResponseErrorsItemSource",
    "KeywordsMatch",
    "Link",
    "LinkParams",
    "Links",
    "LongTextDefinition",
    "LongTextDefinitionFieldConfiguration",
    "LongTextDefinitionParams",
    "LongTextDefinitionWithIncludes",
    "MediaLinkCommon",
    "MediaLinksCollection",
    "Mention",
    "MetadataField",
    "MetadataFieldDefinitionsIndexRequestSort",
    "MetadataResponse",
    "MetadataWithDefinition",
    "MultiSelectValue",
    "MultiUserValue",
    "MultiUserValueMemberOptionsType",
    "NameMatch",
    "NoContent",
    "NotFound",
    "NotFoundError",
    "NotFoundErrorsItem",
    "NotFoundErrorsItemSource",
    "NotesMatch",
    "NumberDefinition",
    "NumberDefinitionFieldConfiguration",
    "NumberDefinitionFieldConfigurationNumberFormat",
    "NumberDefinitionParams",
    "NumberDefinitionParamsFieldConfiguration",
    "NumberDefinitionParamsFieldConfigurationNumberFormat",
    "NumberDefinitionWithIncludes",
    "NumberValue",
    "OriginalMediaLink",
    "PageCountMatch",
    "Project",
    "ProjectInclude",
    "ProjectMatch",
    "ProjectMatchInfo",
    "ProjectMatchProject",
    "ProjectSearchResult",
    "ProjectSort",
    "ProjectStatus",
    "ProjectUserRolesIndexRequestSort",
    "ProjectUserRolesResponse",
    "ProjectWithIncludes",
    "ProjectsIndexRequestSort",
    "ProjectsWithIncludesResponse",
    "RatingDefinition",
    "RatingDefinitionFieldConfiguration",
    "RatingDefinitionFieldConfigurationStyle",
    "RatingDefinitionParams",
    "RatingDefinitionParamsFieldConfiguration",
    "RatingDefinitionParamsFieldConfigurationStyle",
    "RatingDefinitionWithIncludes",
    "RatingMatch",
    "RenditionMediaLink",
    "RequestAfterOpaqueCursor",
    "RequestPageSize",
    "ResolutionHeightMatch",
    "ResolutionWidthMatch",
    "ReviewersSort",
    "ScrubSheetMediaLink",
    "ScrubSheetMediaLinkMetadata",
    "SearchMatch",
    "SearchParamsEngine",
    "SearchParamsFilters",
    "SearchResponse",
    "SearchResponseDataItem",
    "SelectDefinition",
    "SelectDefinitionFieldConfiguration",
    "SelectDefinitionFieldConfigurationOptionsItem",
    "SelectDefinitionParams",
    "SelectDefinitionParamsFieldConfiguration",
    "SelectDefinitionParamsFieldConfigurationOptionsItem",
    "SelectDefinitionWithIncludes",
    "SelectMultiDefinition",
    "SelectMultiDefinitionFieldConfiguration",
    "SelectMultiDefinitionFieldConfigurationOptionsItem",
    "SelectMultiDefinitionParams",
    "SelectMultiDefinitionParamsFieldConfiguration",
    "SelectMultiDefinitionParamsFieldConfigurationOptionsItem",
    "SelectMultiDefinitionWithIncludes",
    "SelectOption",
    "SelectValue",
    "Share",
    "ShareAccess",
    "ShareReviewersResponse",
    "ShareSort",
    "SharesIndexRequestSort",
    "SharesListReviewersRequestSort",
    "SharesResponse",
    "SingleUserValue",
    "SingleUserValueMemberOptionsType",
    "SourceFilenameMatch",
    "StatusMatch",
    "SyncGroupWithIncludes",
    "SyncGroupWithIncludesSyncStatus",
    "TextDefinition",
    "TextDefinitionFieldConfiguration",
    "TextDefinitionParams",
    "TextDefinitionWithIncludes",
    "TextReviewAnnotation",
    "TextReviewAnnotationBounds",
    "TextReviewAnnotationTextReviewAnnotationType",
    "TextReviewAnnotationUpdate",
    "TextReviewAnnotationUpdateTextReviewAnnotationType",
    "TextValue",
    "TimeStamp",
    "ToggleDefinition",
    "ToggleDefinitionFieldConfiguration",
    "ToggleDefinitionParams",
    "ToggleDefinitionParamsFieldConfiguration",
    "ToggleDefinitionWithIncludes",
    "TooManyRequests",
    "TooManyRequestsError",
    "TooManyRequestsErrorsItem",
    "TooManyRequestsErrorsItemSource",
    "TranscriptionMatch",
    "TranscriptionMatchMatchesItem",
    "Unauthorized",
    "UnauthorizedError",
    "UnauthorizedErrorsItem",
    "UnauthorizedErrorsItemSource",
    "UnprocessableContent",
    "UnprocessableContentErrorsItem",
    "UnprocessableContentErrorsItemSource",
    "UnprocessableEntityError",
    "UpdateAccountRolesResponse",
    "UpdateCommentParamsData",
    "UpdateDateDefinitionParams",
    "UpdateDateDefinitionParamsFieldConfiguration",
    "UpdateDateDefinitionParamsFieldConfigurationDisplayFormat",
    "UpdateDateDefinitionParamsFieldConfigurationTimeFormat",
    "UpdateFieldDefinitionParamsData",
    "UpdateGroupParamsData",
    "UpdateLongTextDefinitionParams",
    "UpdateNumberDefinitionParams",
    "UpdateNumberDefinitionParamsFieldConfiguration",
    "UpdateNumberDefinitionParamsFieldConfigurationNumberFormat",
    "UpdateRatingDefinitionParams",
    "UpdateRatingDefinitionParamsFieldConfiguration",
    "UpdateRatingDefinitionParamsFieldConfigurationStyle",
    "UpdateSelectDefinitionParams",
    "UpdateSelectDefinitionParamsFieldConfiguration",
    "UpdateSelectDefinitionParamsFieldConfigurationOptionsItem",
    "UpdateSelectMultiDefinitionParams",
    "UpdateSelectMultiDefinitionParamsFieldConfiguration",
    "UpdateSelectMultiDefinitionParamsFieldConfigurationOptionsItem",
    "UpdateTextDefinitionParams",
    "UpdateToggleDefinitionParams",
    "UpdateToggleDefinitionParamsFieldConfiguration",
    "UpdateUserMultiDefinitionParams",
    "UpdateUserMultiDefinitionParamsFieldConfiguration",
    "UpdateUserMultiDefinitionParamsFieldConfigurationCustomMembersItem",
    "UpdateUserMultiDefinitionParamsFieldConfigurationCustomMembersItemType",
    "UpdateUserMultiDefinitionParamsFieldConfigurationMemberOptionsType",
    "UpdateUserRolesParamsData",
    "UpdateUserRolesParamsDataRole",
    "UpdateUserRolesResponse",
    "UpdateUserRolesResponseData",
    "UpdateUserRolesResponseDataRole",
    "UpdateUserSingleDefinitionParams",
    "UpdateUserSingleDefinitionParamsFieldConfiguration",
    "UpdateUserSingleDefinitionParamsFieldConfigurationCustomMembersItem",
    "UpdateUserSingleDefinitionParamsFieldConfigurationCustomMembersItemType",
    "UpdateUserSingleDefinitionParamsFieldConfigurationMemberOptionsType",
    "UpdatedAtMatch",
    "UploadedAtMatch",
    "User",
    "UserMultiDefinition",
    "UserMultiDefinitionFieldConfiguration",
    "UserMultiDefinitionFieldConfigurationCustomMembersItem",
    "UserMultiDefinitionFieldConfigurationCustomMembersItemType",
    "UserMultiDefinitionFieldConfigurationMemberOptionsType",
    "UserMultiDefinitionParams",
    "UserMultiDefinitionParamsFieldConfiguration",
    "UserMultiDefinitionParamsFieldConfigurationCustomMembersItem",
    "UserMultiDefinitionParamsFieldConfigurationCustomMembersItemType",
    "UserMultiDefinitionParamsFieldConfigurationMemberOptionsType",
    "UserMultiDefinitionWithIncludes",
    "UserRole",
    "UserRoleRole",
    "UserRoleSort",
    "UserRolesResponse",
    "UserSingleDefinition",
    "UserSingleDefinitionFieldConfiguration",
    "UserSingleDefinitionFieldConfigurationCustomMembersItem",
    "UserSingleDefinitionFieldConfigurationCustomMembersItemType",
    "UserSingleDefinitionFieldConfigurationMemberOptionsType",
    "UserSingleDefinitionParams",
    "UserSingleDefinitionParamsFieldConfiguration",
    "UserSingleDefinitionParamsFieldConfigurationCustomMembersItem",
    "UserSingleDefinitionParamsFieldConfigurationCustomMembersItemType",
    "UserSingleDefinitionParamsFieldConfigurationMemberOptionsType",
    "UserSingleDefinitionWithIncludes",
    "UserValue",
    "UserValueType",
    "Uuid",
    "VersionStack",
    "VersionStackAssetsWithIncludesResponse",
    "VersionStackChildrenResponse",
    "VersionStackCreateParamsData",
    "VersionStackMoveParamsData",
    "VersionStackReorderParamsData",
    "VersionStackReorderParamsDataMoveTo",
    "VersionStackResponse",
    "VersionStackSortIndex",
    "VersionStackSortList",
    "VersionStackWithIncludes",
    "VersionStackWithIncludesResponse",
    "VersionStacksIndexRequestInclude",
    "VersionStacksIndexRequestSort",
    "VersionStacksListRequestInclude",
    "VersionStacksListRequestSort",
    "VersionStacksShowRequestInclude",
    "VersionStacksWithIncludesResponse",
    "VisualMatch",
    "VisualMatchClip",
    "VisualMatchClipsItem",
    "Webhook",
    "WebhookEvents",
    "WebhookSort",
    "WebhookWithIncludes",
    "WebhooksIndexRequestSort",
    "WebhooksWithIncludesResponse",
    "Workspace",
    "WorkspaceInclude",
    "WorkspaceSort",
    "WorkspaceUserRolesIndexRequestSort",
    "WorkspaceUserRolesResponse",
    "WorkspaceWithIncludes",
    "WorkspacesIndexRequestSort",
    "WorkspacesWithIncludesResponse",
    "__version__",
    "account_permissions",
    "accounts",
    "collections",
    "comments",
    "custom_actions",
    "files",
    "folder_permissions",
    "folders",
    "groups",
    "metadata",
    "metadata_fields",
    "project_permissions",
    "projects",
    "search",
    "shares",
    "version_stacks",
    "webhooks",
    "workspace_permissions",
    "workspaces",
]



# This file was auto-generated by Fern from our API Definition.

import typing

AssetSearchResultType = typing.Union[typing.Literal["file_result", "folder_result", "version_stack_result"], typing.Any]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel
from .project_match_project import ProjectMatchProject


class ProjectMatch(UniversalBaseModel):
    """
    The asset's project name is a match for the search query
    """

    project: ProjectMatchProject = pydantic.Field()
    """
    Project information for a project match
    """

    terms: typing.List[str] = pydantic.Field()
    """
    The terms in the search query that matched the project name
    """

    type: typing.Literal["project_match"] = "project_match"

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel
from .visual_match_clips_item import VisualMatchClipsItem


class VisualMatch(UniversalBaseModel):
    """
    The result's content vector embedding is a match for the search query
    """

    clips: typing.List[VisualMatchClipsItem] = pydantic.Field()
    """
    The list of subclips matching the query
    """

    type: typing.Literal["visual_match"] = "visual_match"

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.include_total_count import IncludeTotalCount
from ..types.request_after_opaque_cursor import RequestAfterOpaqueCursor
from ..types.request_page_size import RequestPageSize
from ..types.update_user_roles_response import UpdateUserRolesResponse
from ..types.user_roles_response import UserRolesResponse
from ..types.uuid_ import Uuid
from .raw_client import AsyncRawFolderPermissionsClient, RawFolderPermissionsClient
from .types.update_user_roles_params_data import UpdateUserRolesParamsData

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class FolderPermissionsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawFolderPermissionsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawFolderPermissionsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawFolderPermissionsClient
        """
        return self._raw_client

    def folder_user_roles_index(
        self,
        account_id: Uuid,
        folder_id: Uuid,
        *,
        include_deactivated: typing.Optional[bool] = None,
        after: typing.Optional[RequestAfterOpaqueCursor] = None,
        page_size: typing.Optional[RequestPageSize] = None,
        include_total_count: typing.Optional[IncludeTotalCount] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> UserRolesResponse:
        """
        List user roles for a given folder. <br/>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        folder_id : Uuid


        include_deactivated : typing.Optional[bool]
            Supports including deactivated users in the response. Default is false.

        after : typing.Optional[RequestAfterOpaqueCursor]
            Opaque Cursor query param for requests returning paginated results.
            <br/>
            NOTE: this value is auto-generated and included as part of links from a previous response. It is not intended to be human readable.

        page_size : typing.Optional[RequestPageSize]


        include_total_count : typing.Optional[IncludeTotalCount]


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        UserRolesResponse
            OK

        Examples
        --------
        from frameio_experimental import FrameioExperimental

        client = FrameioExperimental(
            api_version="YOUR_API_VERSION",
            token="YOUR_TOKEN",
        )
        client.folder_permissions.folder_user_roles_index(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            folder_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            include_deactivated=True,
            after="<opaque_cursor>",
            page_size=10,
            include_total_count=False,
        )
        """
        _response = self._raw_client.folder_user_roles_index(
            account_id,
            folder_id,
            include_deactivated=include_deactivated,
            after=after,
            page_size=page_size,
            include_total_count=include_total_count,
            request_options=request_options,
        )
        return _response.data

    def delete(
        self,
        account_id: Uuid,
        folder_id: Uuid,
        user_id: Uuid,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> None:
        """
        Remove a user from a given folder. <br/>Rate Limits: 60 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        folder_id : Uuid


        user_id : Uuid


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        from frameio_experimental import FrameioExperimental

        client = FrameioExperimental(
            api_version="YOUR_API_VERSION",
            token="YOUR_TOKEN",
        )
        client.folder_permissions.delete(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            folder_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            user_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
        )
        """
        _response = self._raw_client.delete(account_id, folder_id, user_id, request_options=request_options)
        return _response.data

    def folder_user_roles_update(
        self,
        account_id: Uuid,
        folder_id: Uuid,
        user_id: Uuid,
        *,
        data: UpdateUserRolesParamsData,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> UpdateUserRolesResponse:
        """
        Update user roles for the given folder if the user is already added to the folder. If the user is
            not added to the folder, the user will be added with the given role. <br/>Rate Limits: 10 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        folder_id : Uuid


        user_id : Uuid


        data : UpdateUserRolesParamsData

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        UpdateUserRolesResponse
            OK

        Examples
        --------
        from frameio_experimental import FrameioExperimental
        from frameio_experimental.folder_permissions import UpdateUserRolesParamsData

        client = FrameioExperimental(
            api_version="YOUR_API_VERSION",
            token="YOUR_TOKEN",
        )
        client.folder_permissions.folder_user_roles_update(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            folder_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            user_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            data=UpdateUserRolesParamsData(
                role="editor",
            ),
        )
        """
        _response = self._raw_client.folder_user_roles_update(
            account_id, folder_id, user_id, data=data, request_options=request_options
        )
        return _response.data


class AsyncFolderPermissionsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawFolderPermissionsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawFolderPermissionsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawFolderPermissionsClient
        """
        return self._raw_client

    async def folder_user_roles_index(
        self,
        account_id: Uuid,
        folder_id: Uuid,
        *,
        include_deactivated: typing.Optional[bool] = None,
        after: typing.Optional[RequestAfterOpaqueCursor] = None,
        page_size: typing.Optional[RequestPageSize] = None,
        include_total_count: typing.Optional[IncludeTotalCount] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> UserRolesResponse:
        """
        List user roles for a given folder. <br/>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        folder_id : Uuid


        include_deactivated : typing.Optional[bool]
            Supports including deactivated users in the response. Default is false.

        after : typing.Optional[RequestAfterOpaqueCursor]
            Opaque Cursor query param for requests returning paginated results.
            <br/>
            NOTE: this value is auto-generated and included as part of links from a previous response. It is not intended to be human readable.

        page_size : typing.Optional[RequestPageSize]


        include_total_count : typing.Optional[IncludeTotalCount]


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        UserRolesResponse
            OK

        Examples
        --------
        import asyncio

        from frameio_experimental import AsyncFrameioExperimental

        client = AsyncFrameioExperimental(
            api_version="YOUR_API_VERSION",
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.folder_permissions.folder_user_roles_index(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                folder_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                include_deactivated=True,
                after="<opaque_cursor>",
                page_size=10,
                include_total_count=False,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.folder_user_roles_index(
            account_id,
            folder_id,
            include_deactivated=include_deactivated,
            after=after,
            page_size=page_size,
            include_total_count=include_total_count,
            request_options=request_options,
        )
        return _response.data

    async def delete(
        self,
        account_id: Uuid,
        folder_id: Uuid,
        user_id: Uuid,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> None:
        """
        Remove a user from a given folder. <br/>Rate Limits: 60 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        folder_id : Uuid


        user_id : Uuid


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio

        from frameio_experimental import AsyncFrameioExperimental

        client = AsyncFrameioExperimental(
            api_version="YOUR_API_VERSION",
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.folder_permissions.delete(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                folder_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                user_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete(account_id, folder_id, user_id, request_options=request_options)
        return _response.data

    async def folder_user_roles_update(
        self,
        account_id: Uuid,
        folder_id: Uuid,
        user_id: Uuid,
        *,
        data: UpdateUserRolesParamsData,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> UpdateUserRolesResponse:
        """
        Update user roles for the given folder if the user is already added to the folder. If the user is
            not added to the folder, the user will be added with the given role. <br/>Rate Limits: 10 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        folder_id : Uuid


        user_id : Uuid


        data : UpdateUserRolesParamsData

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        UpdateUserRolesResponse
            OK

        Examples
        --------
        import asyncio

        from frameio_experimental import AsyncFrameioExperimental
        from frameio_experimental.folder_permissions import UpdateUserRolesParamsData

        client = AsyncFrameioExperimental(
            api_version="YOUR_API_VERSION",
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.folder_permissions.folder_user_roles_update(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                folder_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                user_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                data=UpdateUserRolesParamsData(
                    role="editor",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.folder_user_roles_update(
            account_id, folder_id, user_id, data=data, request_options=request_options
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel
from .select_definition_params_field_configuration_options_item import (
    SelectDefinitionParamsFieldConfigurationOptionsItem,
)


class SelectDefinitionParamsFieldConfiguration(UniversalBaseModel):
    enable_add_new: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Allow or disallow adding in new option(s) from the grid/list view
    """

    options: typing.List[SelectDefinitionParamsFieldConfigurationOptionsItem]

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import UniversalBaseModel
from ...types.anchor import Anchor
from ...types.attachment_input import AttachmentInput
from ...types.link_params import LinkParams
from ...types.text_review_annotation import TextReviewAnnotation
from ...types.time_stamp import TimeStamp


class CreateCommentParamsData(UniversalBaseModel):
    anchor: typing.Optional[Anchor] = pydantic.Field(default=None)
    """
    Comment anchor location. {(x, y) | 0 <= x <= 1, 0 <= y <= 1}.
    """

    annotation: typing.Optional[str] = pydantic.Field(default=None)
    """
    JSON geometry for on-screen drawings. Allowed for document, image, video, or stream file types. JSON must be stringified
    """

    attachments: typing.Optional[typing.List[AttachmentInput]] = pydantic.Field(default=None)
    """
    Optional attachments to create with the comment (max 6 attachments)
    """

    completed: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Comment completion status
    """

    duration: typing.Optional[int] = pydantic.Field(default=None)
    """
    Duration of comment in frames. Requires presence of timestamp parameter
    """

    links: typing.Optional[typing.List[LinkParams]] = pydantic.Field(default=None)
    """
    Comment text links.
    """

    page: typing.Optional[int] = pydantic.Field(default=None)
    """
    Document page. Only allowed when file type is a pdf document
    """

    text: str = pydantic.Field()
    """
    Comment text (required)
    """

    text_review_annotation: typing.Optional[TextReviewAnnotation] = pydantic.Field(default=None)
    """
    Text review annotation details for comments left on text documents.
    """

    timestamp: typing.Optional[TimeStamp] = None

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel
from .text_review_annotation_bounds import TextReviewAnnotationBounds
from .text_review_annotation_update_text_review_annotation_type import (
    TextReviewAnnotationUpdateTextReviewAnnotationType,
)


class TextReviewAnnotationUpdate(UniversalBaseModel):
    """
    Payload for updating an existing text review annotation.
    """

    bounds: typing.Optional[typing.List[TextReviewAnnotationBounds]] = pydantic.Field(default=None)
    """
    Optional bounds array. When omitted, previously stored bounds are preserved.
    """

    selection_text: typing.Optional[str] = pydantic.Field(default=None)
    """
    Optional selection text override.
    """

    suggested_text: typing.Optional[str] = pydantic.Field(default=None)
    """
    Optional suggestion override.
    """

    text_review_annotation_type: typing.Optional[TextReviewAnnotationUpdateTextReviewAnnotationType] = pydantic.Field(
        default=None
    )
    """
    Optional annotation type override.
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import UniversalBaseModel
from .version_stack_reorder_params_data_move_to import VersionStackReorderParamsDataMoveTo


class VersionStackReorderParamsData(UniversalBaseModel):
    move_above_file_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    UUID of the file to move the target file above
    """

    move_below_file_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    UUID of the file to move the target file below
    """

    move_to: typing.Optional[VersionStackReorderParamsDataMoveTo] = pydantic.Field(default=None)
    """
    Move the target file to the top or bottom of the version stack
    """

    target_file_id: str = pydantic.Field()
    """
    UUID of the file to move
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel
from .text_review_annotation_bounds import TextReviewAnnotationBounds
from .text_review_annotation_text_review_annotation_type import TextReviewAnnotationTextReviewAnnotationType


class TextReviewAnnotation(UniversalBaseModel):
    bounds: typing.List[TextReviewAnnotationBounds] = pydantic.Field()
    """
    An array of bounds representing a multiline selection origin at the lower-left corner.
    """

    selection_text: typing.Optional[str] = pydantic.Field(default=None)
    """
    Selected text from the document.
    """

    suggested_text: typing.Optional[str] = pydantic.Field(default=None)
    """
    Suggested replacement or insertion text.
    """

    text_review_annotation_type: TextReviewAnnotationTextReviewAnnotationType = pydantic.Field()
    """
    The type of text review annotation. 
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel


class VisualMatchClipsItem(UniversalBaseModel):
    """
    A subclip within a video that is a match for the search query
    """

    best_frame_time: int = pydantic.Field()
    """
    Best matching frame time in milliseconds
    """

    end_time: int = pydantic.Field()
    """
    End time in milliseconds
    """

    index: int = pydantic.Field()
    """
    Chronological index of this clip
    """

    relevancy_index: int = pydantic.Field()
    """
    Index ordered by relevancy score
    """

    start_time: int = pydantic.Field()
    """
    Start time in milliseconds
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel


class Mention(UniversalBaseModel):
    end_index: int = pydantic.Field()
    """
    End index of mention text
    """

    start_index: int = pydantic.Field()
    """
    Start index of mention text
    """

    text: str = pydantic.Field()
    """
    Mention text
    """

    user_id: str = pydantic.Field()
    """
    Mentioned user ID
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.include_total_count import IncludeTotalCount
from ..types.request_after_opaque_cursor import RequestAfterOpaqueCursor
from ..types.request_page_size import RequestPageSize
from ..types.search_response import SearchResponse
from ..types.uuid_ import Uuid
from .raw_client import AsyncRawSearchClient, RawSearchClient
from .types.search_params_engine import SearchParamsEngine
from .types.search_params_filters import SearchParamsFilters

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class SearchClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawSearchClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawSearchClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawSearchClient
        """
        return self._raw_client

    def search(
        self,
        account_id: Uuid,
        *,
        engine: SearchParamsEngine,
        query: str,
        after: typing.Optional[RequestAfterOpaqueCursor] = None,
        page_size: typing.Optional[RequestPageSize] = None,
        include_total_count: typing.Optional[IncludeTotalCount] = None,
        filters: typing.Optional[SearchParamsFilters] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SearchResponse:
        """
        Search across assets, folders, and projects within an account.
        Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        engine : SearchParamsEngine
            Search engine to use. Available engines: lexical, nlp.

        query : str
            The search query text

        after : typing.Optional[RequestAfterOpaqueCursor]
            Opaque Cursor query param for requests returning paginated results.
            <br/>
            NOTE: this value is auto-generated and included as part of links from a previous response. It is not intended to be human readable.

        page_size : typing.Optional[RequestPageSize]


        include_total_count : typing.Optional[IncludeTotalCount]


        filters : typing.Optional[SearchParamsFilters]
            Filters to control which types of results are returned

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SearchResponse
            OK

        Examples
        --------
        from frameio_experimental import FrameioExperimental
        from frameio_experimental.search import SearchParamsFilters

        client = FrameioExperimental(
            api_version="YOUR_API_VERSION",
            token="YOUR_TOKEN",
        )
        client.search.search(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            after="<opaque_cursor>",
            page_size=10,
            include_total_count=False,
            engine="nlp",
            filters=SearchParamsFilters(
                files_and_version_stacks=True,
                folders=False,
                projects=False,
            ),
            query="red car driving on highway",
        )
        """
        _response = self._raw_client.search(
            account_id,
            engine=engine,
            query=query,
            after=after,
            page_size=page_size,
            include_total_count=include_total_count,
            filters=filters,
            request_options=request_options,
        )
        return _response.data


class AsyncSearchClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawSearchClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawSearchClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawSearchClient
        """
        return self._raw_client

    async def search(
        self,
        account_id: Uuid,
        *,
        engine: SearchParamsEngine,
        query: str,
        after: typing.Optional[RequestAfterOpaqueCursor] = None,
        page_size: typing.Optional[RequestPageSize] = None,
        include_total_count: typing.Optional[IncludeTotalCount] = None,
        filters: typing.Optional[SearchParamsFilters] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SearchResponse:
        """
        Search across assets, folders, and projects within an account.
        Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        engine : SearchParamsEngine
            Search engine to use. Available engines: lexical, nlp.

        query : str
            The search query text

        after : typing.Optional[RequestAfterOpaqueCursor]
            Opaque Cursor query param for requests returning paginated results.
            <br/>
            NOTE: this value is auto-generated and included as part of links from a previous response. It is not intended to be human readable.

        page_size : typing.Optional[RequestPageSize]


        include_total_count : typing.Optional[IncludeTotalCount]


        filters : typing.Optional[SearchParamsFilters]
            Filters to control which types of results are returned

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SearchResponse
            OK

        Examples
        --------
        import asyncio

        from frameio_experimental import AsyncFrameioExperimental
        from frameio_experimental.search import SearchParamsFilters

        client = AsyncFrameioExperimental(
            api_version="YOUR_API_VERSION",
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.search.search(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                after="<opaque_cursor>",
                page_size=10,
                include_total_count=False,
                engine="nlp",
                filters=SearchParamsFilters(
                    files_and_version_stacks=True,
                    folders=False,
                    projects=False,
                ),
                query="red car driving on highway",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.search(
            account_id,
            engine=engine,
            query=query,
            after=after,
            page_size=page_size,
            include_total_count=include_total_count,
            filters=filters,
            request_options=request_options,
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

CommentSort = typing.Union[
    typing.Literal[
        "owner_asc", "owner_desc", "completed_at_asc", "completed_at_desc", "created_at_asc", "created_at_desc"
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel
from .field_value_common_field_type import FieldValueCommonFieldType


class FieldValueCommon(UniversalBaseModel):
    """
    Metadata field value
    """

    field_definition_id: str = pydantic.Field()
    """
    Field definition ID
    """

    field_definition_name: str = pydantic.Field()
    """
    Field definition name
    """

    field_type: FieldValueCommonFieldType = pydantic.Field()
    """
    Field type
    """

    mutable: bool = pydantic.Field()
    """
    Metadata mutability. System field values cannot be updated.
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel
from .user import User


class ShareReviewersResponse(UniversalBaseModel):
    """
    Share reviewers
    """

    data: typing.List[User] = pydantic.Field()
    """
    Share reviewer details
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel


class UploadedAtMatch(UniversalBaseModel):
    """
    The result's uploaded at timestamp is a match for the search query
    """

    type: typing.Literal["uploaded_at_match"] = "uploaded_at_match"
    uploaded_at: dt.datetime = pydantic.Field()
    """
    The uploaded at timestamp of the result
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.update_date_definition_params import UpdateDateDefinitionParams
from ...types.update_long_text_definition_params import UpdateLongTextDefinitionParams
from ...types.update_number_definition_params import UpdateNumberDefinitionParams
from ...types.update_rating_definition_params import UpdateRatingDefinitionParams
from ...types.update_select_definition_params import UpdateSelectDefinitionParams
from ...types.update_select_multi_definition_params import UpdateSelectMultiDefinitionParams
from ...types.update_text_definition_params import UpdateTextDefinitionParams
from ...types.update_toggle_definition_params import UpdateToggleDefinitionParams
from ...types.update_user_multi_definition_params import UpdateUserMultiDefinitionParams
from ...types.update_user_single_definition_params import UpdateUserSingleDefinitionParams

UpdateFieldDefinitionParamsData = typing.Union[
    UpdateDateDefinitionParams,
    UpdateLongTextDefinitionParams,
    UpdateNumberDefinitionParams,
    UpdateRatingDefinitionParams,
    UpdateSelectDefinitionParams,
    UpdateSelectMultiDefinitionParams,
    UpdateTextDefinitionParams,
    UpdateToggleDefinitionParams,
    UpdateUserMultiDefinitionParams,
    UpdateUserSingleDefinitionParams,
]



# This file was auto-generated by Fern from our API Definition.

import typing

ProjectUserRolesIndexRequestSort = typing.Union[
    typing.Literal["role_asc", "role_desc", "name_asc", "name_desc", "email_asc", "email_desc"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel


class AudioSampleRateMatch(UniversalBaseModel):
    """
    The result's audio sample rate is a match for the search query
    """

    audio_sample_rate: float = pydantic.Field()
    """
    The audio sample rate of the result in Hz
    """

    type: typing.Literal["audio_sample_rate_match"] = "audio_sample_rate_match"

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

from .file_with_includes import FileWithIncludes
from .folder_with_includes import FolderWithIncludes
from .version_stack_with_includes import VersionStackWithIncludes

AssetWithIncludes = typing.Union[FileWithIncludes, FolderWithIncludes, VersionStackWithIncludes]



# This file was auto-generated by Fern from our API Definition.

import typing

FolderSort = typing.Union[
    typing.Literal["name_asc", "created_at_asc", "updated_at_asc", "name_desc", "created_at_desc", "updated_at_desc"],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel


class ResolutionHeightMatch(UniversalBaseModel):
    """
    The result's resolution height is a match for the search query
    """

    resolution_height: float = pydantic.Field()
    """
    The resolution height of the result in pixels
    """

    type: typing.Literal["resolution_height_match"] = "resolution_height_match"

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

from .group_common_with_includes import GroupCommonWithIncludes
from .sync_group_with_includes import SyncGroupWithIncludes

GroupWithIncludes = typing.Union[SyncGroupWithIncludes, GroupCommonWithIncludes]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from .action import Action
from .user import User


class ActionCreateResponseData(Action):
    creator: typing.Optional[User] = None
    secret: str = pydantic.Field()
    """
    Secret used to validate underlying webhook requests. Make sure to store your secret. You won’t be able to see it again!
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel


class BitRateMatch(UniversalBaseModel):
    """
    The result's bit rate is a match for the search query
    """

    bit_rate: float = pydantic.Field()
    """
    The bit rate of the result in bps
    """

    type: typing.Literal["bit_rate_match"] = "bit_rate_match"

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import UniversalBaseModel


class ActionUpdateParamsData(UniversalBaseModel):
    active: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Active Status
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Action description
    """

    event: typing.Optional[str] = pydantic.Field(default=None)
    """
    Event name sent to `url`
    """

    multi_asset: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Manages action trigger on multiple assets
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Action name
    """

    timeout: typing.Optional[int] = pydantic.Field(default=None)
    """
    Timeout for the action requests in seconds
    """

    url: typing.Optional[str] = pydantic.Field(default=None)
    """
    URL where `event` is sent
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel
from .unprocessable_content_errors_item_source import UnprocessableContentErrorsItemSource


class UnprocessableContentErrorsItem(UniversalBaseModel):
    detail: str
    source: typing.Optional[UnprocessableContentErrorsItemSource] = None
    title: typing.Optional[str] = None

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel


class ProjectMatchInfo(UniversalBaseModel):
    """
    Project information for a project match
    """

    id: str = pydantic.Field()
    """
    The project ID
    """

    name: str = pydantic.Field()
    """
    The project name
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

SharesListReviewersRequestSort = typing.Union[typing.Literal["name_asc", "active", "name_desc", "inactive"], typing.Any]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import UniversalBaseModel


class SearchParamsFilters(UniversalBaseModel):
    """
    Filters to control which types of results are returned
    """

    files_and_version_stacks: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Include files and version stacks in search results
    """

    folders: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Include folders in search results
    """

    projects: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Include projects in search results
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel
from .project import Project
from .search_match import SearchMatch


class ProjectSearchResult(UniversalBaseModel):
    """
    A search result containing a project
    """

    matches: typing.List[SearchMatch] = pydantic.Field()
    """
    Matches explaining why this result was returned
    """

    result: Project
    type: typing.Literal["project_result"] = "project_result"

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.parse_error import ParsingError
from ..core.pydantic_utilities import parse_obj_as
from ..core.request_options import RequestOptions
from ..errors.bad_request_error import BadRequestError
from ..errors.conflict_error import ConflictError
from ..errors.forbidden_error import ForbiddenError
from ..errors.not_found_error import NotFoundError
from ..errors.too_many_requests_error import TooManyRequestsError
from ..errors.unauthorized_error import UnauthorizedError
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.bad_request import BadRequest
from ..types.conflict import Conflict
from ..types.forbidden import Forbidden
from ..types.include_total_count import IncludeTotalCount
from ..types.not_found import NotFound
from ..types.request_after_opaque_cursor import RequestAfterOpaqueCursor
from ..types.request_page_size import RequestPageSize
from ..types.too_many_requests import TooManyRequests
from ..types.unauthorized import Unauthorized
from ..types.uuid_ import Uuid
from ..types.workspace_user_roles_response import WorkspaceUserRolesResponse
from .types.workspace_user_roles_index_request_sort import WorkspaceUserRolesIndexRequestSort
from pydantic import ValidationError


class RawWorkspacePermissionsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def workspace_user_roles_index(
        self,
        account_id: Uuid,
        workspace_id: Uuid,
        *,
        include_deactivated: typing.Optional[bool] = None,
        sort: typing.Optional[WorkspaceUserRolesIndexRequestSort] = None,
        after: typing.Optional[RequestAfterOpaqueCursor] = None,
        page_size: typing.Optional[RequestPageSize] = None,
        include_total_count: typing.Optional[IncludeTotalCount] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[WorkspaceUserRolesResponse]:
        """
        List user roles for a given workspace. <br/>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        workspace_id : Uuid


        include_deactivated : typing.Optional[bool]
            Supports including deactivated users in the response. Default is false.

        sort : typing.Optional[WorkspaceUserRolesIndexRequestSort]
            Sort users by query params

        after : typing.Optional[RequestAfterOpaqueCursor]
            Opaque Cursor query param for requests returning paginated results.
            <br/>
            NOTE: this value is auto-generated and included as part of links from a previous response. It is not intended to be human readable.

        page_size : typing.Optional[RequestPageSize]


        include_total_count : typing.Optional[IncludeTotalCount]


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[WorkspaceUserRolesResponse]
            OK
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v4/accounts/{jsonable_encoder(account_id)}/workspaces/{jsonable_encoder(workspace_id)}/users",
            method="GET",
            params={
                "include_deactivated": include_deactivated,
                "sort": sort,
                "after": after,
                "page_size": page_size,
                "include_total_count": include_total_count,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    WorkspaceUserRolesResponse,
                    parse_obj_as(
                        type_=WorkspaceUserRolesResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        BadRequest,
                        parse_obj_as(
                            type_=BadRequest,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        Unauthorized,
                        parse_obj_as(
                            type_=Unauthorized,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        Forbidden,
                        parse_obj_as(
                            type_=Forbidden,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        NotFound,
                        parse_obj_as(
                            type_=NotFound,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 409:
                raise ConflictError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        Conflict,
                        parse_obj_as(
                            type_=Conflict,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        TooManyRequests,
                        parse_obj_as(
                            type_=TooManyRequests,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        except ValidationError as e:
            raise ParsingError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.json(), cause=e
            )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawWorkspacePermissionsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def workspace_user_roles_index(
        self,
        account_id: Uuid,
        workspace_id: Uuid,
        *,
        include_deactivated: typing.Optional[bool] = None,
        sort: typing.Optional[WorkspaceUserRolesIndexRequestSort] = None,
        after: typing.Optional[RequestAfterOpaqueCursor] = None,
        page_size: typing.Optional[RequestPageSize] = None,
        include_total_count: typing.Optional[IncludeTotalCount] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[WorkspaceUserRolesResponse]:
        """
        List user roles for a given workspace. <br/>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        workspace_id : Uuid


        include_deactivated : typing.Optional[bool]
            Supports including deactivated users in the response. Default is false.

        sort : typing.Optional[WorkspaceUserRolesIndexRequestSort]
            Sort users by query params

        after : typing.Optional[RequestAfterOpaqueCursor]
            Opaque Cursor query param for requests returning paginated results.
            <br/>
            NOTE: this value is auto-generated and included as part of links from a previous response. It is not intended to be human readable.

        page_size : typing.Optional[RequestPageSize]


        include_total_count : typing.Optional[IncludeTotalCount]


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[WorkspaceUserRolesResponse]
            OK
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v4/accounts/{jsonable_encoder(account_id)}/workspaces/{jsonable_encoder(workspace_id)}/users",
            method="GET",
            params={
                "include_deactivated": include_deactivated,
                "sort": sort,
                "after": after,
                "page_size": page_size,
                "include_total_count": include_total_count,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    WorkspaceUserRolesResponse,
                    parse_obj_as(
                        type_=WorkspaceUserRolesResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        BadRequest,
                        parse_obj_as(
                            type_=BadRequest,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        Unauthorized,
                        parse_obj_as(
                            type_=Unauthorized,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        Forbidden,
                        parse_obj_as(
                            type_=Forbidden,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        NotFound,
                        parse_obj_as(
                            type_=NotFound,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 409:
                raise ConflictError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        Conflict,
                        parse_obj_as(
                            type_=Conflict,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        TooManyRequests,
                        parse_obj_as(
                            type_=TooManyRequests,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        except ValidationError as e:
            raise ParsingError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.json(), cause=e
            )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel
from .asset_common import AssetCommon
from .asset_search_result_type import AssetSearchResultType
from .search_match import SearchMatch


class AssetSearchResult(UniversalBaseModel):
    """
    A search result containing an asset (file, folder, or version stack)
    """

    matches: typing.List[SearchMatch] = pydantic.Field()
    """
    Matches explaining why this result was returned
    """

    result: AssetCommon
    type: AssetSearchResultType

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
